@@ -20,13 +20,17 @@ class RelatedDrives(PluginTemplateExtension):
         volumes = WindowsVolume.objects.filter(
             virtual_machine=obj
         )
+        unmapped_drives = Drive.objects.filter(
+            virtual_machine=obj
+        )
 
         platform = obj.platform
         if platform.name.__contains__('Windows'):
             return self.render(
                 "netbox_storage/volume/windowsvolume_box.html",
                 extra_context={
-                    "volumes": volumes
+                    "volumes": volumes,
+                    "unmapped_drives": unmapped_drives
                 },
             )
         else:
